# -*- coding: utf-8 -*-

__authors__= "Juan Colino & Jorge Diez"
__email__= "juan.colino@gmail.com"
__license__= """
 --------------------------------------------------------------------------

 Waltz 0.1 - GTK Icon Management System
 Copyright (C) 2007 Juan Colino
 <juan.colino@gmail.com>

 --------------------------------------------------------------------------

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 --------------------------------------------------------------------------
"""


import pygtk
pygtk.require('2.0')
import gobject
import gtk
import gtk.gdk
import Image
import pango

class MainWindow:
    "Clase que modela la ventana principal de la aplicacion"

    app = None
    prefs = None

    def __init__(self, app, prefs):
	"Crea la ventana con todos sus componentes"
	
	self.prefs = prefs
	self.app = app

	# creamos window
	self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	self.window.set_icon(gtk.gdk.pixbuf_new_from_file('waltz.svg'))
	self.window.connect("delete_event", self.delete_event)
	self.window.connect("destroy", self.destroy)
	self.window.set_border_width(0)
	self.window.set_title("Waltz")
	self.window.set_position(gtk.WIN_POS_CENTER)
	self.window.set_default_size(self.prefs.prefs_dict['window width'],
	    self.prefs.prefs_dict['window height'])

	#  ########################################################################
	#  |                        gtk.VBox (vbox1)                              |
	#  |                                                                      |
	#  |  ##################################################################  |
	#  |  |     gtk.MenuBar (menubar)                                      |  |
	#  |  ##################################################################  |
	#  |  ##################################################################  |
	#  |  |     gtk.Toolbar (toolbar)                                      |  |
	#  |  ##################################################################  |
	#  |                                                                      |
	#  |  ##################################################################  |
	#  |  |     gtk.HBox (hbox)                                            |  |
	#  |  |                                                                |  |
	#  |  |  #######################   ############################        |  |
	#  |  |  |  gtk.VBox (vbox2)   |   |                          |        |  |
	#  |  |  |                     |   |                          |        |  |
	#  |  |  |  gtk.Label (label1) |   |                          |        |  |
	#  |  |  |  gtk.Label (label2) |   |  gtk.TreeView (treeview) |        |  |
	#  |  |  |  gtk.Label (label3) |   |                          |        |  |
	#  |  |  |                     |   |                          |        |  |
	#  |  |  #######################   ############################        |  |
	#  |  |                                                                |  |
	#  |  ##################################################################  |
	#  |                                                                      |
	#  |  ##################################################################  |
	#  |  |     gtk.Statusbar (satusbar)                                   |  |
	#  |  ##################################################################  |
	#  |                                                                      |
	#  ########################################################################

	# creamos vbox1
	self.vbox1 = gtk.VBox()

	# creamos la barra de menu y la barra de herramientas
	ui_description = """<ui>
	  <menubar name='Menubar'>
	    <menu action='FileMenu'>
	      <menuitem action='OpenDir'/>
	      <menuitem action='OpenTheme'/>
	      <separator/>
	      <menuitem action='Quit'/>
	    </menu>
	    <menu action='HelpMenu'>
	      <menuitem action='About'/>
	    </menu>
	  </menubar>
	  <toolbar name='Toolbar'>
	    <toolitem action='OpenDir'/>
	    <separator/>
	    <toolitem action='Quit'/>
	  </toolbar>
	</ui>"""

	self.action_group = gtk.ActionGroup('WindowActions')
	self.actions = [
            ('FileMenu', None, '_File'),
            ('New',      gtk.STOCK_NEW, '_New', '<control>N',
             'Create a new file', self.create_about_dialog),
            ('OpenDir',     gtk.STOCK_OPEN, '_Open Dir', '<control>O',
             'Open a directory', self.create_opendir_dialog),
	    ('OpenTheme', gtk.STOCK_OPEN, 'Open _Theme', '<control>T',
	     'Open a theme', self.create_opentheme_dialog),
            ('Quit',     gtk.STOCK_QUIT, '_Quit', '<control>Q',
             'Quit application', self.destroy),
            ('HelpMenu', None, '_Help'),
            ('About',    gtk.STOCK_ABOUT, '_About', None, 'About application',
             self.create_about_dialog),
            ]
	self.action_group.add_actions(self.actions)

	self.ui = gtk.UIManager()
	self.ui.insert_action_group(self.action_group, 0)
	self.ui.add_ui_from_string(ui_description)
	self.window.add_accel_group(self.ui.get_accel_group())

	self.vbox1.pack_start(self.ui.get_widget('/Menubar'), expand = False)
	self.vbox1.pack_start(self.ui.get_widget('/Toolbar'), expand = False)

	# creamos hbox
	self.hbox = gtk.HBox()

	# creamos vpane
	self.hpane = gtk.HPaned()
	self.hbox.pack_start(self.hpane, padding = 5)

	# creamos vbox2
	self.vbox2 = gtk.VBox()

	# creamos las etiquetas y las empaquetamos en vbox2
	self.label1 = gtk.Label("label1")
	self.label1.set_max_width_chars(30)
	self.label1.set_ellipsize(pango.ELLIPSIZE_END)
	self.label1.show()
	self.label2 = gtk.Label("label2")
	self.label2.show()
	self.label3 = gtk.Label("label3")
	self.label3.show()
	self.vbox2.pack_start(child = self.label1, expand = False, fill=False, padding = 5)
	self.vbox2.pack_start(child = self.label2, expand = False, fill=False, padding = 5)
	self.vbox2.pack_start(child = self.label3, expand = False, fill=False, padding = 5)
	self.vbox2.show()

	# empaquetamos vbox2 en hbox
#	self.hbox.pack_start(child=self.vbox2, expand=False, padding=5)

	self.hpane.pack1(self.vbox2, resize = False, shrink = False)
	self.hpane.set_position(100)


	# creamos la gtk.ListStore y lo usamos para crear el treeview
	self.liststore = gtk.ListStore(str, gtk.gdk.Pixbuf)
	self.treeview = gtk.TreeView(self.liststore)
	self.treeview.set_headers_visible(False)

	# FIXME: ajustar propiedades

#	self.treeview.set_rules_hint(True)
#	self.treeview.set_reorderable(False)
#	self.treeview.set_enable_search(False)
#	self.treeview_selection = self.treeview.get_selection()
	self.treeview_text_cell = gtk.CellRendererText()
	self.treeview_pix_cell = gtk.CellRendererPixbuf()
	self.treeview_column = gtk.TreeViewColumn()
	self.treeview_column.pack_start(self.treeview_text_cell, True)
	self.treeview_column.pack_start(self.treeview_pix_cell, True)
	self.treeview_column.set_attributes(self.treeview_text_cell, markup=0)
	self.treeview_column.set_attributes(self.treeview_pix_cell, pixbuf=1)
#	self.treeview_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
	self.treeview.append_column(self.treeview_column)
#	self.treeview.set_fixed_height_mode(True)	
	self.treeview.show()

	# creamos la scrolled_window y empaquetamos en ella el treeview
	self.scrolled_window = gtk.ScrolledWindow()
	self.scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
	self.scrolled_window.show()
	self.scrolled_window.add_with_viewport(self.treeview)

	# empaquetamos la scrolled_window en hbox
#	self.hbox.pack_start(self.scrolled_window)
	#self.hbox.show()

	self.hpane.pack2(self.scrolled_window, resize = False, shrink = False)
	self.hpane.show()
	self.hbox.show()


	# empaquetamos hbox en vbox1
	self.vbox1.pack_start(self.hbox)
	
	# creamos la barra de estado
	self.statusbar = gtk.Statusbar()
	self.statusbar.show()

	# empaquetamos la barra de estado
	self.vbox1.pack_start(child = self.statusbar, expand = False)
	self.vbox1.show()

	# agregamos vbox1 a la ventana principal
	self.window.add(self.vbox1)
	self.window.show()

    def show_icons(self, icon_list):
	"Muestra una lista de iconos en el treeview"

	self.liststore.clear()
	for icon in icon_list:
	    icon_path = icon.get_path_to_file()
	    icon_name = icon.get_icon_name()
	    pixbuf = gtk.gdk.pixbuf_new_from_file(icon_path) 
	    self.liststore.append([icon_name, pixbuf])

    def show_status(self, status_string, context):
	"Muestra un estado (status_string) en la barra de estado en un contexto (context)"

	context_id = self.statusbar.get_context_id(context)
	self.statusbar.pop(context_id)
	message_id = self.statusbar.push(context_id, status_string)
	return message_id

    def create_about_dialog(self, event):
	"Crea el cuadro de dialogo about y sus widgets"

#	self.about_dialog = gtk.AboutDialog()
#	self.about_dialog.set_name('Waltz')
#	self.about_dialog.set_version('0.1')
#	self.about_dialog.set_copyright('Juan Colino')
#	self.about_dialog.set_comments('Waltz is an icon management system designed to handle icon themes')
#	self.about_dialog.set_license(__license__)
#	self.about_dialog.set_website('http://csl-waltz-forja.rediris.es')
#	self.about_dialog.set_website_label('WebSite')
#	self.about_dialog.set_authors(['Juan Colino Barrigón <juan.colino@gmail.com>'])
#	icon_pixbuf = gtk.gdk.pixbuf_new_from_file_at_size("waltz.svg", 150, 150)
#	self.about_dialog.set_logo(icon_pixbuf)
#	self.about_dialog.show()

	# ===========
	# About tab
	# ===========

	color1 = '#333333'
	color2 = '#793566'

	self.about_dialog = gtk.Dialog("About", self.window, 0, (gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
	self.about_dialog.set_has_separator(False)
	self.about_dialog.set_resizable(False)
	box = gtk.VBox(False, 0)
	box.set_border_width(5)
	notebook = gtk.Notebook()
	self.about_dialog.vbox.pack_start(notebook, False, False, 0)
	icon_pixbuf = gtk.gdk.pixbuf_new_from_file_at_size("waltz.svg", 150, 150)
	icon_image = gtk.Image()
	icon_image.set_from_pixbuf(icon_pixbuf)
	box.pack_start(icon_image, False, False, 10)
	label = gtk.Label()
	# FIXME: limpieza
	label.set_markup(
            '<big><big><big><big><b><span foreground="' + color1 + '">Wal</span>' +
   	    '<span foreground="' + color2 + '">tz</span> <span foreground="' + color1 + '">' +
            self.app.version +
            '</span></b></big></big></big></big>\n' +
            "\n" +
            "Waltz is an icon management system designed to handle icon themes." +
            "\n" +
            "It can open icon themes from index.theme files." +
            "\n" +
            "Waltz is licensed under the GNU General Public License." + "\n" +
            "\n" +
	    "<small>Copyright © 2007 Juan Colino &amp; Jorge Diez\n\n" +
	    "juan.colino@gmail.com</small>\n" +
	    "<small>http://csl-waltz.forja.rediris.es</small>\n")
    	box.pack_start(label, True, True, 0)
	label.set_justify(gtk.JUSTIFY_CENTER)

	notebook.insert_page(box, gtk.Label("About"))
        
        # =======================================================
        # Credits tab.
        # =======================================================
	box = gtk.VBox(False, 5)
	box.set_border_width(5)

	for nice_person in (('Pontus Ekberg', 'code inspiration'), ('Colaborator name', 'task')):
	    label = gtk.Label()
	    label.set_markup('<b>' + nice_person[0] + ':</b>   ' +
	    nice_person[1])
	    box.pack_start(label, False, False, 0)
	    label.set_alignment(0, 0)

	notebook.insert_page(box, gtk.Label("Credits"))
	self.about_dialog.vbox.show_all()
	self.about_dialog.run()
	self.about_dialog.destroy()

    def create_opentheme_dialog(self, event):
	pass

    def create_opendir_dialog(self, event):
	"Crea el cuadro de dialogo open y sus widgets"
	open_dialog = gtk.FileChooserDialog("Open directory", self.window, gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
		(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
	open_dialog.set_default_response(gtk.RESPONSE_OK)

	# creamos un filtro
#	filter = gtk.FileFilter()
#	filter.set_name("Directories")
#	filter.add_mime_type("inode/directory")
#	open_dialog.add_filter(filter)

	response = open_dialog.run()
	if response == gtk.RESPONSE_OK:
	    print open_dialog.get_filename() + ' selected...'
	    self.app.read_icons_from_directory(open_dialog.get_filename())
	elif response == gtk.RESPONSE_CANCEL:
	    pass
	open_dialog.destroy()
	
    def delete_event(self, widget, event, data=None):
	print "delete event occurred"
	return False

    def destroy(self, widget, data=None):
	gtk.main_quit()

